/**
 * @typedef {NodeJS.WritableStream} WritableStream
 * @typedef {import("../../type/index.js").Level} Level
 * @typedef {import("../../type/index.js").Notice} Notice
 */
/**
 * Le formateur qui écrit les résultats brut (au format JSON). La seul
 * altération des résultats est le remplacement des <code>undefined</code> par
 * des <code>null</code>.
 *
 * @see https://www.json.org/
 */
export default class JSONFormatter extends Formatter {
    /**
     * Crée un formateur.
     *
     * @param {Level}          level            Le niveau de sévérité minimum
     *                                          des notifications affichées.
     * @param {Object}         options          Les options du formateur.
     * @param {WritableStream} [options.writer] Le flux où écrire les résultats.
     * @param {number}         [options.indent] La taille des indentations (en
     *                                          espace).
     */
    constructor(level: Level, options: {
        writer?: WritableStream;
        indent?: number;
    });
    #private;
}
export type WritableStream = NodeJS.WritableStream;
export type Level = import("../../type/index.js").Level;
export type Notice = import("../../type/index.js").Notice;
import Formatter from "./formatter.js";
